@@ -4,6 +4,7 @@ use std::convert::{TryFrom, Into, TryInto};
 use url::{Url};
 use rotorlib::protocol::Package;
 use rotorlib::streaming_client::LightClient;
+use rotorlib::rpc_client;
 use crate::structs::TinkoffApiKey;
 
 
@@ -196,6 +197,28 @@ pub enum Message{
     Service(ServiceMessage),
 }
 
+pub struct Sender{
+    server_url: Url
+}
+
+impl Sender{
+    pub fn new(server_url: Url) -> Self{ Self{server_url} }
+    pub fn new_str(server_url: &str) -> Result<Self, ()>{
+        let server_url: Url = match server_url.parse(){
+            Ok(url) => {
+                let url: Url = url;
+                url
+            }
+            Err(_) => { return Err(()) }
+        };
+        Ok(Self{server_url})
+    }
+    pub async fn send(&self, payload: Payload) -> Result<(), ()>{
+        rpc_client::send_msg(self.server_url.clone(),
+                             payload.into()).await
+    }
+}
+
 pub struct Api{
     client: LightClient
 }
