@@ -54,7 +54,7 @@ impl Api{
         }
         Err(())
     }
-    pub async fn set_key(&self, name: String, key: String) -> Result<f64, ()>{
+    pub async fn set_key(&self, name: String, key: String) -> Result<i64, ()>{
         let uri = format!("{}/set", self.keys_service_path.clone()).parse();
         if let Ok(uri) = uri{
             let uri: Uri = uri;
@@ -88,7 +88,7 @@ pub struct KeySetReqBody{
 
 #[derive(Deserialize, Serialize, Debug)]
 pub struct KeySetResp{
-    pub time: f64
+    pub time: i64
 }
 
 #[derive(Deserialize, Serialize, Debug)]
